@@ -1,9 +1,5 @@
-from kivy.properties import (
-    ObjectProperty,
-    BooleanProperty,
-    ListProperty,
-    DictProperty
-)
+from kivy.properties import (ObjectProperty, BooleanProperty, ListProperty,
+                             DictProperty)
 
 from ..imagestackproxy import ImageStackProxy
 from ..pawn import PawnBehavior
@@ -14,8 +10,4 @@ class GridPawn(ImageStackProxy, PawnBehavior):
 
     def __repr__(self):
         """Give my ``thing``'s name and its location's name."""
-        return '<{}-in-{} at {}>'.format(
-            self.name,
-            self.loc_name,
-            id(self)
-        )
+        return '<{}-in-{} at {}>'.format(self.name, self.loc_name, id(self))
